semimetric.BAGIDIS(DATA1,DATA2=DATA1, p = 2, wk=NULL, Param=0.5, wdw= min(ncol(DATA1),30), Evol =FALSE, Overlap = wdw-1, method = c('TS','BD'))
semimetric.BAGIDIS.TS(DATA1,DATA2=DATA1, p = 2, wk=NULL, Param=0.5, wdw= min(ncol(DATA1),30), Evol =FALSE, Overlap = wdw-1)
semimetric.BAGIDIS.BD(Details1, Breakpoints1,Details2=Details1, Breakpoints2=Breakpoints1,NbSubseries =1,p = 2, wk=NULL, Param=0.5, Evol =FALSE)
BAGIDIS.dist(BUUHWE.out.1, BUUHWE.out.2, p = 2, wk=NULL, Param=0.5)
BAGIDIS.dist.BD(Details1, Breakpoints1,Details2, Breakpoints2,
p = 2, wk=NULL, Param=0.5)DATA2 Each row of DATA1 has its semidistance being computed with every row of DATA2. If only DATA1 is provided, then DATA2 is taken to be equal to DATA1. We must have ncol(DATA1)= ncol(DATA2).
DATA1 Each row of DATA1 has its semidistance being computed with every row of DATA2. If only DATA1 is provided, then DATA2 is taken to be equal to DATA1. We must have ncol(DATA1)= ncol(DATA2)Inf.
ncol(DATA1)-1. If not provided, wk = log(N+1-(1:N))/log(N+1) with N= ncol(DATA1)-1.
Param= 1 means that only breakpoints differences are taken into account. Param=0 means that only details differences are taken into account.
wdw encode the length of the window in which the semimetric will be computed between the subseries. By default there is no windowing if the length of the series ( = ncol(DATA1) ) is smaller than or equal to 30, and a windows length of 30 otherwise.
FALSE.
Overlap determines how the subseries overlap each other. By default, a one-step-sliding distance is computed.
DATA1 and DATA2.
If nrow(DATA1)> nrow(DATA2), it increases the number of operations to be computed.
On the opposite, if nrow(DATA2)>nrow(DATA1), it increases the memory usage.BUUHWE.BUUHWE.nrow(DATA1) series of DATA1 and the nrow(DATA2) series of DATA2. Dimensions: nrow(DATA1) x nrow(DATA2) .
DATA1 and DATA2. Dimensions: nrow(DATA1) x nrow(DATA2) x Nb_subseries. Nb_subseries is determined by the three quantities nrow(DATA1), wdw and Overlap.
semimetric.BAGIDIS computes the Bagidis semidistance between curves.
If several curves are provided, it returns a matrix of semidistances.
The function is an interface for either semimetric.BAGIDIS.TS or semimetric.BAGIDIS.BD, depending on the value of the parameter method.Function Bagidis.dist computes the BAGIDIS semidistance between two series, encoded through their BUUHWE expansion obtained from function BUUHWE. Function Bagidis.dist.BD computes the BAGIDIS semidistance between two series, encoded through their breakpoints and details obtained from functions Breakpoints and Details.
See BAGIDIS-package for an overview about the BAGIDIS methodology and References for details, in particular Timmermans (2012), Chapter 1, and Timmermans and von Sachs (2010).
The main references are
Other references include
The function BUUHWE_2D in this package is similar to the function uh.bu.2d (copyrighted Fryzlewicz 2014) in the package "shah_code", available on the webpage of Piotr Fryzlewicz: http://stats.lse.ac.uk/fryzlewicz/shah/shah_code.R , which accompanies the paper Fryzlewicz and Timmermans (2015).
BUUHWE, semimetric.BAGIDIS_2D.
x= 1:10
y=2:11
A=rbind(x,y)
semimetric.BAGIDIS(A)
B= rbind(x,x,y)
semimetric.BAGIDIS(A,B)
x= 1:30
y= 1:30
A= rbind(x,y)
B= rbind(x,x, y)
semimetric.BAGIDIS(A,B, wdw =15, Evol =TRUE, Overlap =0)
x= c(1,7,3,0,-2,6,4,0,2)
y= c(1,7,5,5,-2,1,4,0,2)
BAGIDIS.dist(BUUHWE(x), BUUHWE(y))
Run the code above in your browser using DataLab